bluemath\_tk package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bluemath_tk.core
   bluemath_tk.datamining
   bluemath_tk.distributions
   bluemath_tk.downloaders
   bluemath_tk.interpolation
   bluemath_tk.predictor
   bluemath_tk.risk
   bluemath_tk.tc
   bluemath_tk.teslakit
   bluemath_tk.tide
   bluemath_tk.topo_bathy
   bluemath_tk.waves
   bluemath_tk.wrappers

Module contents
---------------

.. automodule:: bluemath_tk
   :members:
   :undoc-members:
   :show-inheritance:
